from rest_framework import mixins
from rest_framework import viewsets
from rest_framework.renderers import JSONRenderer

from .models import Category, FAQ
from .serializers import CategorySerializer, FAQSerializer


class BaseViewSet(
    mixins.ListModelMixin,
    viewsets.GenericViewSet):
    renderer_classes = [JSONRenderer]
    pagination_class = None


class FAQViewSet(BaseViewSet):
    queryset = FAQ.objects.order_by('order')
    serializer_class = FAQSerializer


class FAQCategoryViewSet(BaseViewSet):
    queryset = Category.objects.order_by('order', 'name')
    serializer_class = CategorySerializer



from rest_framework import serializers

from .models import Category, FAQ


class FAQSerializer(serializers.ModelSerializer):

    class Meta:
        model = FAQ
        fields = ['order', 'question', 'answer']


class CategorySerializer(serializers.ModelSerializer):
    faqs = FAQSerializer(many=True)

    class Meta:
        model = Category
        fields = ['order', 'name', 'faqs']



# Generated by Django 2.2.2 on 2019-06-04 18:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('faq', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='faq',
            options={'ordering': ['order']},
        ),
        migrations.AddField(
            model_name='faq',
            name='order',
            field=models.PositiveIntegerField(default=None),
            preserve_default=False,
        ),
    ]



from django.contrib import admin

from .models import Category, FAQ


class FAQInline(admin.TabularInline):
    extra = 0
    model = FAQ
    fields = ['order', 'question', 'answer']


@admin.register(Category)
class CategoryAdmin(admin.ModelAdmin):
    list_display = ['name', 'order']
    list_editable = ['order']
    search_fields = ['name']
    inlines = [FAQInline]


@admin.register(FAQ)
class FAQAdmin(admin.ModelAdmin):
    list_display = ['question', 'category', 'order', 'created_at', 'updated_at']
    list_filter = ['category']
    list_editable = ['order']
    search_fields = ['question', 'answer', 'category__name']



from django.conf import settings
try:
    from django.urls import include, path
except ImportError:
    from django.conf.urls import include, url as path

from rest_framework.documentation import include_docs_urls
from rest_framework.routers import DefaultRouter

from . import views


router = DefaultRouter()


router.register('faqs', views.FAQViewSet, 'api-faq')
router.register('', views.FAQCategoryViewSet, 'api-category')


urlpatterns = [
    path('', include(router.urls))
]



# Generated by Django 2.2.2 on 2019-06-04 18:40

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Category',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=128)),
            ],
            options={
                'verbose_name_plural': 'Categories',
            },
        ),
        migrations.CreateModel(
            name='FAQ',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('question', models.CharField(max_length=128)),
                ('answer', models.TextField()),
                ('category', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='faqs', to='faq.Category')),
            ],
        ),
    ]
